@@ -1,25 +1,54 @@
 #' A Monte Carlo Option Pricing Algorithm for Jump Diffusion Model with Correlation Companies
-#' @param  companies_data a matrix of a correlation coefficient of companies
-#' @param  companies an integer of company number in order to simulate.
-#' @param  simulation.length an integer of a duration of simulation.
-#' @param  monte_carlo an integer of iterations of monte carlo.
-#' @param  start_price a vector of company's initial stock prices.
-#' @param  mu a vector of parameter of geometric Brownian motion.
-#' @param  sigma a vector of parameter of geometric Brownian motion.
-#' @param  event_times an integer of how many times jump in Unit time.
-#' @param  jump a vector of jump parameter.
-#' @param  K a vector of option execution prices.
-#' @param  color a vector of colors in plot.
-#' @return premium a list of (call_premium, put_premium)
+#' @param  companies_data : a matrix of a correlation coefficient of companies
+#' @param  companies : an integer of a company number in order to simulate.
+#' @param  simulation.length : an integer of a time duration of simulation.
+#' @param  monte_carlo : an integer of an iteration number for monte carlo.
+#' @param  start_price : a vector of company's initial stock prices.
+#' @param  mu : a vector of drift parameters of geometric Brownian motion.
+#' @param  sigma : a vector of volatility parameters of geometric Brownian motion.
+#' @param  event_times : an integer of how many times jump in unit time.
+#' @param  jump : a vector of jump parameter.
+#' @param  K : a vector of option strike prices.
+#' @param  color : a vector of colors in plot.
+#' @return option prices : a list of (call_price, put_price)
 #' @examples
-#' jdm_new_bs(matrix(c(1,0.2,0.3,0.4,1,0.6,0.7,0.8,1), nrow=3, ncol=3),
-#' 3, simulation.length=60,monte_carlo=60, c(1000,500,500), c(0.005, 0.025, 0.01),
-#' c(0.08,0.04,0.06), 3, c(0.1,0.1,0.1), c(2500,3000,1500), c("red","blue","green"))
+#' price <- jdm_new_bs(matrix(c(0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9),nrow=3, ncol=3),
+#'                     3, simulation.length=100,monte_carlo=80, c(1000,500,500),
+#'                     c(0.002, 0.012, 0.005),c(0.05,0.05,0.06), 3,c(0.1,0.1,0.1),
+#'                     c(1500,1000,700),c("red","blue","green")
+#'                    )
 #' @export
-jdm_new_bs<- function(companies_data, companies, simulation.length=180, monte_carlo=1000, start_price, mu,sigma, event_times, jump, K, color) {
+jdm_new_bs<- function(companies_data, companies, simulation.length=180, monte_carlo=1000, start_price=start_price, mu=mu,sigma=sigma, event_times=event_times, jump=jump, K=K, color=color) {
+  if(is.matrix(companies_data) == FALSE){
+    print("Error: Input companies_data type is not matrix.")
+    return(FALSE)
+  }
+  if(is.numeric(companies) == FALSE){
+    print("Error: Input companies type is not numeric.")
+    return(FALSE)
+  }
+  if(companies <= 0){
+    print("Error: Input companies is less than or equal to zero.")
+    return(FALSE)
+  }
+  if(is.numeric(simulation.length) == FALSE){
+    print("Error: Input simulation.length type is not integer.")
+    return(FALSE)
+  }
+  if(simulation.length <= 0){
+    print("Error: Input simulation.length is less than or equal to zero.")
+    return(FALSE)
+  }
+  if(is.numeric(monte_carlo) == FALSE){
+    print("Error: Input monte_carlo type is not integer.")
+    return(FALSE)
+  }
+  if(monte_carlo <= 0){
+    print("Error: Input monte_carlo is less than or equal to zero.")
+    return(FALSE)
+  }
   price_sim <-array(0, c(companies, monte_carlo));
   price <- array(0, c(monte_carlo, companies, simulation.length))
-  premium <- c()
   price_up_limit_graph <- 0;
   price_down_limit_graph <- 0;
   dW <- array(0, c(companies))
@@ -81,7 +110,7 @@ jdm_new_bs<- function(companies_data, companies, simulation.length=180, monte_ca
   }
   for(count in 1 : monte_carlo){
     if(count == 1){
-      plot(price[count, 1, ], xlab="t", ylab="price", ylim = c(price_down_limit_graph, price_up_limit_graph), xlim=c(1, simulation.length), xaxp=c(1, simulation.length,simulation.length/10), type="l", col="black", lwd = 0.10, cex.axis = 0.6, cex.lab = 0.8)
+      plot(price[count, 1, ], xlab="t", ylab="price", ylim = c(price_down_limit_graph, price_up_limit_graph), xlim=c(1, simulation.length), xaxp=c(0, simulation.length,simulation.length/10), type="l", col="black", lwd = 0.10, cex.axis = 0.6, cex.lab = 0.8)
       par(new=T)
       plot(x = jump_time[count,1:jump_time_count[count]], y = 1 : jump_time_count[count] - 1, type = "s", xlim = c(1, simulation.length),axes=FALSE,lwd = 0.10,xlab="",ylab="")
       par(new=T)
@@ -103,36 +132,36 @@ jdm_new_bs<- function(companies_data, companies, simulation.length=180, monte_ca
   title(main = "Geometric Brownian Motion", col.main="black", font.main=1, cex.main = 0.8)
   #legend(1,8000, c("mu = 0.7,  sigma = 0.5"), cex=0.8, col=c("black"), pch=1, lty=1);
 
-  call_premium <- numeric(companies);
-  put_premium <- numeric(companies);
+  call_price <- array(0,c(companies));
+  put_price <- array(0,c(companies));
   for(i in 1 : companies){
     for(count in 1 : monte_carlo){
       if((price_sim[i,count] - K[i]) <= 0){
-        call_premium[i] <- call_premium[i] + 0
+        call_price[i] <- call_price[i] + 0
       }
       else{
-        call_premium[i] <- call_premium[i] + price_sim[i,count]
+        call_price[i] <- call_price[i] + (price_sim[i,count] - K[i])
       }
     }
-    call_premium[i] <- call_premium[i] / monte_carlo;
+    call_price[i] <- call_price[i] / monte_carlo;
   }
   for(i in 1:companies){
     for(count in 1 : monte_carlo){
       if((K[i] - price_sim[i,count]) <= 0){
-        put_premium[i] <- put_premium[i] + 0;
+        put_price[i] <- put_price[i] + 0;
       }
       else{
-        put_premium[i] <- put_premium[i] + price_sim[i,count]
+        put_price[i] <- put_price[i] + (K[i] - price_sim[i,count])
       }
     }
-    put_premium[i] <- put_premium[i] / monte_carlo;
+    put_price[i] <- put_price[i] / monte_carlo;
   }
   print("Call Option Price:")
-  print(call_premium)
+  print(call_price)
   print("Put Option Price:")
-  print(put_premium)
-  names(call_premium) <- "Call Option Price"
-  names(put_premium) <- "Put Option Price"
-  premium <- list(call_premium,put_premium)
-  return (invisible(premium))
+  print(put_price)
+  names(call_price) <- "Call Option Price"
+  names(put_price) <- "Put Option Price"
+  price <- list(call_price,put_price)
+  return (invisible(price))
 }
